aboutsummaryrefslogtreecommitdiffstats
path: root/src/empathy-accounts-dialog.c
diff options
context:
space:
mode:
authorEmanuele Aina <emanuele.aina@collabora.com>2013-04-03 19:14:33 +0800
committerMarco Barisione <marco.barisione@collabora.co.uk>2013-08-20 18:03:04 +0800
commit42456ae2a2c758db70cc093679d05675293758cb (patch)
tree1e546367d2d44970c664f841b6834a2b8890fb8e /src/empathy-accounts-dialog.c
parent75df7ae67b78f94dd69ac5c6ad079e3d360c8461 (diff)
downloadgsoc2013-empathy-42456ae2a2c758db70cc093679d05675293758cb.tar
gsoc2013-empathy-42456ae2a2c758db70cc093679d05675293758cb.tar.gz
gsoc2013-empathy-42456ae2a2c758db70cc093679d05675293758cb.tar.bz2
gsoc2013-empathy-42456ae2a2c758db70cc093679d05675293758cb.tar.lz
gsoc2013-empathy-42456ae2a2c758db70cc093679d05675293758cb.tar.xz
gsoc2013-empathy-42456ae2a2c758db70cc093679d05675293758cb.tar.zst
gsoc2013-empathy-42456ae2a2c758db70cc093679d05675293758cb.zip
tp-account-widgets: Switch the symbols namespace to tpaw
The file names have been kept unchanged to keep the diff simple and will be updated later. This makes easier to spot where the account widgets still rely on libempathy. https://bugzilla.gnome.org/show_bug.cgi?id=699492
Diffstat (limited to 'src/empathy-accounts-dialog.c')
-rw-r--r--src/empathy-accounts-dialog.c26
1 files changed, 13 insertions, 13 deletions
diff --git a/src/empathy-accounts-dialog.c b/src/empathy-accounts-dialog.c
index 8a582088c..2d971994d 100644
--- a/src/empathy-accounts-dialog.c
+++ b/src/empathy-accounts-dialog.c
@@ -93,19 +93,19 @@ typedef struct {
GtkWidget *spinner;
gboolean loading;
/* We have to keep a weak reference on the actual EmpathyAccountWidget, not
* just its GtkWidget. It is the only reliable source we can query to know if
* there are any unsaved changes to the currently selected account. We can't
* look at the account settings because it does not contain everything that
* can be changed using the EmpathyAccountWidget. For instance, it does not
* contain the state of the "Enabled" checkbox.
*
* Even if we create it ourself, we just get a weak ref and not a strong one
* as EmpathyAccountWidget unrefs itself when the GtkWidget is destroyed.
* That's kinda ugly; cf bgo #640417.
*
* */
- EmpathyAccountWidget *setting_widget;
+ TpawAccountWidget *setting_widget;
gboolean connecting_show;
guint connecting_id;
@@ -518,7 +518,7 @@ empathy_account_dialog_cancel (EmpathyAccountsDialog *dialog)
COL_ACCOUNT_SETTINGS, &settings,
COL_ACCOUNT, &account, -1);
- empathy_account_widget_discard_pending_changes (priv->setting_widget);
+ tpaw_account_widget_discard_pending_changes (priv->setting_widget);
if (account == NULL)
{
@@ -544,7 +544,7 @@ empathy_account_dialog_cancel (EmpathyAccountsDialog *dialog)
static void
empathy_account_dialog_widget_cancelled_cb (
- EmpathyAccountWidget *widget_object,
+ TpawAccountWidget *widget_object,
EmpathyAccountsDialog *dialog)
{
empathy_account_dialog_cancel (dialog);
@@ -590,14 +590,14 @@ account_dialog_create_edit_params_dialog (EmpathyAccountsDialog *dialog)
gtk_window_set_resizable (GTK_WINDOW (subdialog), FALSE);
- priv->setting_widget = (EmpathyAccountWidget *)
- empathy_account_widget_new_for_protocol (settings, FALSE);
+ priv->setting_widget = (TpawAccountWidget *)
+ tpaw_account_widget_new_for_protocol (settings, FALSE);
g_object_add_weak_pointer (G_OBJECT (priv->setting_widget),
(gpointer *) &priv->setting_widget);
if (accounts_dialog_has_valid_accounts (dialog))
- empathy_account_widget_set_other_accounts_exist (
+ tpaw_account_widget_set_other_accounts_exist (
priv->setting_widget, TRUE);
g_signal_connect (priv->setting_widget, "cancelled",
@@ -783,7 +783,7 @@ accounts_dialog_has_pending_change (EmpathyAccountsDialog *dialog,
gtk_tree_model_get (model, &iter, COL_ACCOUNT, account, -1);
return priv->setting_widget != NULL
- && empathy_account_widget_contains_pending_changes (
+ && tpaw_account_widget_contains_pending_changes (
priv->setting_widget);
}
@@ -1395,7 +1395,7 @@ accounts_dialog_selection_change_response_cb (GtkDialog *message_dialog,
GtkTreeSelection *selection;
priv->force_change_row = TRUE;
- empathy_account_widget_discard_pending_changes (
+ tpaw_account_widget_discard_pending_changes (
priv->setting_widget);
path = gtk_tree_row_reference_get_path (priv->destination_row);
@@ -1922,7 +1922,7 @@ accounts_dialog_accounts_model_row_inserted_cb (GtkTreeModel *model,
if (priv->setting_widget != NULL &&
accounts_dialog_has_valid_accounts (dialog))
{
- empathy_account_widget_set_other_accounts_exist (
+ tpaw_account_widget_set_other_accounts_exist (
priv->setting_widget, TRUE);
}
}
@@ -1937,7 +1937,7 @@ accounts_dialog_accounts_model_row_deleted_cb (GtkTreeModel *model,
if (priv->setting_widget != NULL &&
!accounts_dialog_has_valid_accounts (dialog))
{
- empathy_account_widget_set_other_accounts_exist (
+ tpaw_account_widget_set_other_accounts_exist (
priv->setting_widget, FALSE);
}
}
@@ -93,19 +93,19 @@ typedef struct {
GtkWidget *spinner;
gboolean loading;
- /* We have to keep a weak reference on the actual EmpathyAccountWidget, not
+ /* We have to keep a weak reference on the actual TpawAccountWidget, not
* just its GtkWidget. It is the only reliable source we can query to know if
* there are any unsaved changes to the currently selected account. We can't
@@ -93,19 +93,19 @@ typedef struct {
* there are any unsaved changes to the currently selected account. We can't
* look at the account settings because it does not contain everything that
- * can be changed using the EmpathyAccountWidget. For instance, it does not
+ * can be changed using the TpawAccountWidget. For instance, it does not
* contain the state of the "Enabled" checkbox.
*
@@ -93,19 +93,19 @@ typedef struct {
*
* Even if we create it ourself, we just get a weak ref and not a strong one
- * as EmpathyAccountWidget unrefs itself when the GtkWidget is destroyed.
+ * as TpawAccountWidget unrefs itself when the GtkWidget is destroyed.
* That's kinda ugly; cf bgo #640417.
*